import { CommentParser } from "../rdrama/services/CommentParser";
import { Comment } from "../rdrama/models/Comment";
import GameState from "../game/gameState";
import GameFlow from "../game/gameFlow";

class WorkflowOrchestrator {

    /**
     * Executes the defined workflow for processing comments.
     * 
     * @param comment - The comment object to process
     */
    async executeWorkflow(comment: Comment) {
        try {
            const parsedComment = CommentParser.parseCommand(comment)
            if (parsedComment.command === "") return

            let gameState = await GameState.load(comment)
            if (parsedComment.command === 'restart') gameState = await gameState.reset();

            await GameFlow.executeCurrentPhase(gameState, parsedComment.command)
            await gameState.save()

        } catch (error) {
            console.error('An error occurred during workflow execution:', error);
        }
    }


}

export default WorkflowOrchestrator;